pub struct Casper { /* private fields */ }Expand description
LPC-Next0 CASPER
Implementations
Sourceimpl Casper
impl Casper
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn ctrl1(self) -> Reg<Ctrl1, RW>
pub const fn ctrl1(self) -> Reg<Ctrl1, RW>
Contains the opcode mode, iteration count, and result offset (in RAM) and also launches the accelerator. Note: with CP version: CTRL0 and CRTL1 can be written in one go with MCRR.
Sourcepub const fn status(self) -> Reg<Status, RW>
pub const fn status(self) -> Reg<Status, RW>
Indicates operational status and would contain the carry bit if used.